#define BUILD_NUMBER \
	"build-8068406"
#define BUILD_NUMBER_NUMERIC \
	8068406
#define BUILD_NUMBER_NUMERIC_STRING \
	"8068406"
#define PRODUCT_BUILD_NUMBER \
	"product-build-3619"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	3619
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"3619"
